@@ -1,7 +1,12 @@
+import string
+import random
+
+import boto3
 from get_docker_secret import get_docker_secret
 import os
 import aws_encryption_sdk
 from aws_encryption_sdk import LocalCryptoMaterialsCache, CachingCryptoMaterialsManager
+import base64
 
 
 # Cache capacity (maximum number of entries) is required
@@ -11,7 +16,7 @@ cache = LocalCryptoMaterialsCache(MAX_CACHE_SIZE)
 MAX_ENTRY_AGE_SECONDS = 60.0*60.0
 MAX_ENTRY_MESSAGES = 100
 
-FAKE_ENCRYPTION = os.environ.get('AWS_FAKE_ENCRYPTION', False) == 'True'
+FAKE_ENCRYPTION = os.environ.get('AWS_FAKE_ENCRYPTION', 'False') == 'True'
 
 
 class CachingCMM():
@@ -85,4 +90,30 @@ def encrypt(source_plaintext, **kwargs):
     return cmm.encrypt(source_plaintext, **kwargs)
 
 def decrypt(ciphertext, **kwargs):
-    return cmm.decrypt(ciphertext, **kwargs)
\ No newline at end of file
+    return cmm.decrypt(ciphertext, **kwargs)
+
+
+
+def _create_data_key(region=get_docker_secret('AWS_REGION'), account_number=get_docker_secret('AWS_ACCOUNT_NUMBER'), key_id=get_docker_secret('AWS_KEY_ID'), key_spec="AES_256"):
+    """Generate a data key to use when encrypting and decrypting data"""
+
+    key_arn = 'arn:aws:kms:{0}:{1}:key/{2}'.format(region, account_number, key_id)
+
+    # Create data key
+    kms_client = boto3.client("kms", region_name=region)
+    response = kms_client.generate_data_key(KeyId=key_arn, KeySpec=key_spec)
+
+    # Return the encrypted and plaintext data key
+    return response["CiphertextBlob"], base64.b64encode(response["Plaintext"]).decode('utf-8')
+
+def _create_data_key_fake():
+    letters = string.ascii_lowercase
+    key = ''.join(random.choice(letters) for i in range(24))
+    return bytes(key, 'utf-8'), key
+
+
+
+if FAKE_ENCRYPTION:
+    create_data_key = _create_data_key_fake
+else:
+    create_data_key = _create_data_key
\ No newline at end of file
